using System;

using Idrnd.FaceSdk;

class Example
{
    static String IDLIVEFACE_HOME = "c:/idliveface";

    static Pipeline CreatePipeline()
    {
        Console.WriteLine("Initializing...");
        using (InitConfig config = new InitConfig($"{IDLIVEFACE_HOME}/data/pipelines/astraea.json"))
        {
            return new Pipeline("ConfigurablePipeline", config);
        }
    }

    static void ProcessLivenessResult(PipelineResult result)
    {
        Console.WriteLine($"Result: {result}");

        if (result.QualityResult.Score < 0.5)
        {
            Console.WriteLine("Image has a bad quality");
        }
        else if (result.LivenessResult.Probability >= 0.5)
        {
            Console.WriteLine("Image is genuire");
        }
        else
        {
            Console.WriteLine("Image is spoofed");
        }
    }

    static void Main(string[] args)
    {
        try
        {
            using (Pipeline pipeline = CreatePipeline())
            {
                Console.WriteLine("\nChecking liveness for real_face.jpg");

                using (Image image = new Image($"{IDLIVEFACE_HOME}/examples/images/real_face.jpg"))
                {
                    PipelineResult result = pipeline.CheckLiveness(image);
                    ProcessLivenessResult(result);
                }

                Console.WriteLine("\nChecking liveness for spoof_face.jpg");

                using (Image image = new Image($"{IDLIVEFACE_HOME}/examples/images/spoof_face.jpg"))
                {
                    PipelineResult result = pipeline.CheckLiveness(image);
                    ProcessLivenessResult(result);
                }

                Console.WriteLine("\nChecking liveness for face_not_found.jpg");

                using (Image image = new Image($"{IDLIVEFACE_HOME}/examples/images/face_not_found.jpg"))
                {
                    pipeline.CheckLiveness(image);
                }
            }
        }
        catch (FaceException e)
        {
            Console.WriteLine($"Error: {e.Status}, message: {e.Message}");
        }
    }
}
